#
# spec file for package libmlt
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Dan Dennedy asked to disable it since it's buggy and unmaintained (see e.g. http://www.kdenlive.org/mantis/view.php?id=3070)
%bcond_with vdpau

%define _name mlt
%define libname lib%{_name}
%define lversion 6.14.0
%define soname 6
%define _name_pp %{_name}++
%define libname_pp lib%{_name_pp}
%define soname_pp 3

Name:           %{libname}
Version:        6.14.0
Release:        4.1
Summary:        Multimedia framework for television broadcasting
License:        GPL-3.0-or-later
Group:          Development/Libraries/C and C++
Url:            http://www.mltframework.org
Source0:        https://github.com/mltframework/mlt/archive/v%{version}.tar.gz#/%{_name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE libmlt-0.8.2-vdpau.patch reddwarf@opensuse.org -- Make VDPAU support work without the devel package
Patch1:         libmlt-0.8.2-vdpau.patch

BuildRequires:  fdupes
%if 0%{?suse_version} >= 1500
BuildRequires:  gcc-c++
%else
BuildRequires:  gcc7
BuildRequires:  gcc7-c++
#!Buildignore:  libgcc_s1
%endif
BuildRequires:  ladspa-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(frei0r)
BuildRequires:  pkgconfig(gdk-2.0)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libdv)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libquicktime)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(movit)
#!BuildIgnore:  opencv-qt5-devel
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libpostproc)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pangoft2)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(sox)
BuildRequires:  pkgconfig(vidstab)
BuildRequires:  pkgconfig(vorbisfile)
%if %{with vdpau}
BuildRequires:  pkgconfig(vdpau)
# VDPAU support requires it
BuildRequires:  pkgconfig(x11)
%endif

%description
MLT is a multimedia framework for television broadcasting. It
provides a toolkit for broadcasters, video editors, media players,
transcoders and web streamers. The functionality of the system is
provided via an assortment of tools, XML authoring components, and an
plug-in based API.

%package -n %{libname}%{soname}
Summary:        C library API for the MLT multimedia framework
Group:          System/Libraries

%description -n %{libname}%{soname}
MLT is a multimedia framework for television broadcasting. It
provides a toolkit for broadcasters, video editors, media players,
transcoders and web streamers.

This subpackage contains the C library API for MLT.

%package devel
Summary:        Development files for MLT's C language API
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{soname} = %{version}

%description devel
MLT is a multimedia framework for television broadcasting. It
provides a toolkit for broadcasters, video editors, media players,
transcoders and web streamers.

This subpackage contains the headers to make use of the MLT C API.

%package -n %{libname_pp}%{soname_pp}
Summary:        C++ library API for the MLT multimedia framework
Group:          System/Libraries

%description -n %{libname_pp}%{soname_pp}
MLT is a multimedia framework for television broadcasting. It
provides a toolkit for broadcasters, video editors, media players,
transcoders and web streamers.

This subpackage contains the C++ library API for MLT.

%package -n %{libname_pp}-devel
Summary:        Development files for MLT's C++ language API
Group:          Development/Libraries/C and C++
Requires:       %{libname_pp}%{soname_pp} = %{version}
Requires:       %{libname}-devel = %{version}

%description -n %{libname_pp}-devel
MLT is a multimedia framework for television broadcasting. It
provides a toolkit for broadcasters, video editors, media players,
transcoders and web streamers.

This subpackage contains the headers to make use of the MLT C++ API.

%package -n melt
Summary:        Multimedia framework for television broadcasting
Group:          Productivity/Multimedia/Video/Editors and Convertors
Provides:       melt%{soname} = %{version}
Obsoletes:      melt%{soname} < %{version}
Requires:       %{libname}%{soname}-data = %{version}
Requires:       %{libname}%{soname}-modules = %{version}

%description -n melt
MLT is a multimedia framework for television broadcasting. It
provides a toolkit for broadcasters, video editors, media players,
transcoders and web streamers.

The functionality of the system is provided via an assortment of
tools, XML authoring components, and an plug-in based API.

%package -n %{libname}%{soname}-modules
Summary:        Modules for the MLT multimedia framework
Group:          Productivity/Multimedia/Video/Editors and Convertors
Recommends:     frei0r-plugins
Provides:       mlt(%{soname})(avformat)
%if %{with vdpau}
# I would recommend it, but to the best of my knowledge nobody but nvidia provides a backend
Suggests:       %(rpm -qf $(readlink -e %{_libdir}/libvdpau.so) --qf '%{NAME}')
%endif

%description -n %{libname}%{soname}-modules
MLT is a multimedia framework for television broadcasting. It
provides a toolkit for broadcasters, video editors, media players,
transcoders and web streamers.

The functionality of the system is provided via an assortment of
tools, XML authoring components, and an plug-in based API.

%package -n %{libname}%{soname}-data
Summary:        Architecture-independent data files for the MLT multimedia framework
Group:          Productivity/Multimedia/Video/Editors and Convertors
BuildArch:      noarch

%description -n %{libname}%{soname}-data
MLT is a multimedia framework for television broadcasting. It
provides a toolkit for broadcasters, video editors, media players,
transcoders and web streamers.

%package -n python-%{_name}
Summary:        Python bindings for the MLT multimedia framework
Group:          Development/Languages/Python
BuildRequires:  python-devel
BuildRequires:  swig
Requires:       %{libname_pp}%{soname_pp} >= %{version}
Requires:       %{libname}%{soname} >= %{version}
%{py_requires}
Provides:       python-%{_name}%{soname}

%description -n python-%{_name}
MLT is a multimedia framework for television broadcasting. It
provides a toolkit for broadcasters, video editors, media players,
transcoders and web streamers.
This package contains python bindings.

%prep
%setup -q -n %{_name}-%{version}
%patch1

# To complement libmlt-0.8.0-vdpau.patch.
# When vdpau support is not compiled it will break the code. Doesn't matter because the code will not be used anyway.
VDPAU_SONAME=$(objdump -p $(readlink -e %{_libdir}/libvdpau.so) | grep SONAME | sed 's/.*SONAME.* //' | tr -d '\n')
sed "s/__VDPAU_SONAME__/${VDPAU_SONAME}/" -i src/modules/avformat/vdpau.c

%build
test -x "$(type -p gcc-7)" && export CC=gcc-7
test -x "$(type -p g++-7)" && export CXX=g++-7

# WARNING: building opencv module causes multicore issues - boo#1068792
%configure --disable-opencv \
--enable-sdl2 \
%ifnarch %{ix86} x86_64
  --disable-mmx \
  --disable-sse \
  --disable-sse2 \
%endif
--enable-debug \
--enable-gpl --enable-gpl3 \
%ifarch i586
--disable-mmx \
%endif
%if %{with vdpau}
--avformat-vdpau \
%endif
--enable-extra-versioning \
--swig-languages=python
make %{?_smp_mflags}

%install
%make_install
install -Dpm 0644 docs/melt.1 %{buildroot}%{_mandir}/man1/melt%{soname}.1
ln -s melt%{soname}.1 %{buildroot}%{_mandir}/man1/melt.1
install -Dpm 0644 src/swig/python/_%{_name}.so '%{buildroot}%{python_sitearch}/_%{_name}.so'
install -Dpm 0644 src/swig/python/%{_name}.py '%{buildroot}%{python_sitearch}/%{_name}.py'

# Get the modules that need data
for MODULE in %{buildroot}%{_libdir}/mlt-%{soname}/libmlt*.so; do
  echo $MODULE
  MODULEDIR=%{_datadir}/mlt-%{soname}/$(echo $MODULE | sed 's|%{buildroot}%{_libdir}/mlt-%{soname}/libmlt\(.*\).so|\1|')
  echo $MODULEDIR
  if [ -e %{buildroot}$MODULEDIR ]; then
    echo Done $MODULEDIR
    echo $MODULEDIR >> module_data.dirs
  fi;
done

# Pure data modules
for MODULE in feeds lumas; do
    echo %{_datadir}/mlt-%{soname}/$MODULE >> module_data.dirs
done

# Remove the unversioned symbolic links
rm -f %{buildroot}%{_libdir}/mlt
rm -f %{buildroot}%{_datadir}/mlt

# remove dupes
%fdupes -s %{buildroot}%{_datadir}/mlt-6

%post -n %{libname}%{soname} -p /sbin/ldconfig

%postun -n %{libname}%{soname} -p /sbin/ldconfig

%post -n %{libname_pp}%{soname_pp} -p /sbin/ldconfig

%postun -n %{libname_pp}%{soname_pp} -p /sbin/ldconfig

%files -n %{libname}%{soname}
%defattr(0644, root, root, 0755)
%{_libdir}/lib%{_name}.so.%{soname}
%{_libdir}/lib%{_name}.so.%{lversion}

%files devel
%defattr(0644, root, root, 0755)
%{_libdir}/lib%{_name}.so
%{_includedir}/%{_name}
%{_libdir}/pkgconfig/%{_name}-framework.pc

%files -n %{libname_pp}%{soname_pp}
%defattr(0644, root, root, 0755)
%{_libdir}/lib%{_name_pp}.so.%{soname_pp}
%{_libdir}/lib%{_name_pp}.so.%{lversion}

%files -n %{libname_pp}-devel
%defattr(0644, root, root, 0755)
%{_libdir}/lib%{_name_pp}.so
%{_includedir}/%{_name_pp}
%{_libdir}/pkgconfig/%{_name_pp}.pc

%files -n melt
%defattr(0644, root, root, 0755)
%attr(0755, root, root) %{_bindir}/melt%{soname}
%{_mandir}/man1/melt%{soname}.1%{ext_man}
%{_bindir}/melt
%{_mandir}/man1/melt.1%{ext_man}

%files -n %{libname}%{soname}-modules -f module_data.dirs
%defattr(0644, root, root, 0755)
%doc AUTHORS ChangeLog NEWS README
%license GPLv3 COPYING GPL
%{_libdir}/%{_name}-%{soname}/
%dir %{_datadir}/%{_name}-%{soname}/

%files -n %{libname}%{soname}-data
%defattr(0644, root, root, 0755)
%dir %{_datadir}/%{_name}-%{soname}/
%{_datadir}/%{_name}-%{soname}/metaschema.yaml
%{_datadir}/%{_name}-%{soname}/profiles/
%{_datadir}/%{_name}-%{soname}/presets/
%{_datadir}/%{_name}-%{soname}/vid.stab/

%files -n python-%{_name}
%defattr(0644, root, root, 0755)
%{python_sitearch}/_%{_name}.so
%{python_sitearch}/%{_name}.py

%changelog
* Sun Mar 31 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.14.0
  * This version is mostly fixes plus a few API additions and
    filters.
  Framework:
  * Added mlt_profile_lumas_dir().
  * Added mlt_frame_get_unique_properties().
  * Added mlt_playlist_reorder() and Mlt::Playlist::reorder().
  * Added some new convenience constructors to mlt++
    + Producer(mlt_profile profile, const char *id, const char
  * service = NULL)
    + Consumer(mlt_profile profile, const char *id , const char
  * service = NULL)
    + Transition(mlt_profile profile, const char *id, const char
  * arg = NULL)
    + Filter(mlt_profile profile, const char *id, const char
  * service = NULL)
    + Tractor(mlt_profile profile, char *id, char *arg = NULL)
  * Added Mlt::Transition::connect(Service&).
  * Added unit tests for mlt_playlist.
  * Fixed a crash on invalid transition track values in
    mlt_transition.
  * Fixed a deadlock regression in v6.12.0 of mlt_consumer when
    starting from
    a paused state (producer speed=0).
  Modules:
  * The avformat module now requires at least FFmpeg v2.4 or
    Libav 12.
  * Added mask_start and mask_apply filters to the core module.
  * Added qtext filter to qt module.
  * Changed dynamictext and timer filters to use qtext.
  * Fixed number of digits for seconds in timer filter.
  * Added mlt_image_format property to color producer.
  * Improved color accuracy of libswscale RGB->YUV conversion.
  * Fixed frei0r producer not working with tractor.
  * Fixed decklink consumer stalling on dropped frames.
  * Generate lumas for 16:9, 9:16 (vertical), and square aspect
    ratios.
  * Fixed crash in qimage when alpha_size is zero.
  * Fixed the mlt_consumer channels property not being passed to
    multi consumer.
  * Fixed the shape filter for full range color and crashes.
  * Converted the shape filter to use mlt_animation.
  * Added a use_mix property to the shape filter.
  * Fixed invert=1 and mix=100 gives wrong image in shape filter.
  * Fixed a possible free null pointer in the linsys sdi
    consumer.
  * Fixed using destroyed temporary object in qimage.
  * Fixed a possible null pointer dereference in the
    spot_remover filter.
  * Fixed memory leak on swr_convert() failure in swresample
    filter.
  * Fixed possible null pointer dereference in affine when not
    using rect.
  * Fixed loading image sequence on Windows in qimage.
  * Fixed some null pointer crashes using Movit opengl services.
  * Fixed sdl2 consumer crashes during initialization on Linux
    or BSD.
  * Fixed distorted image using melt_file.
  * Fixed qimage build on Qt version < 5.5.
  * Added offset property to the timer filter.
  * Changed the boxblur hori & vert properties' minimum to 0.
  * Fixed crash in duplicate frame on rotated videos.
  * Added automatic scaling and padding to avfilter.
  * Fixed field order when encoding progressive as interlace.
  * Fixed frei0r plugins to use the number of slices from the
    threads property.
  * Fixed over compositing with transparent clips in luma
    transition.
  * Added sliced processing to dissolve-with-alpha using the
    threads property.
  * Added createdate keyword to dynamictext filter.
  * Fixed possible crash changing audio_index in avformat
    producer.
  * Fixed small memory leaks in xml consumer, jackrack, and
    timewarp producer.
  * Fixed compiling opencv module with OpenCV > 3.
  Other:
  * Added vertical video profiles:
    + vertical_hd_30
    + vertical_hd_60
  * Mlt++ now requires C++11 compiler support.
  * Added --disable-windeploy to configure to keep bin & lib
    folders on Windows.
  * Added support for consumer in & out to melt.
  * Fixed color accuracy of lossless/Ut Video preset and use
    pix_fmt yuv422p.
  * Fixed x264 lossless preset to use crf=0.
  * Fixed compiling with mingw32.
  * Fixed build with Python 3.
* Mon Nov 26 2018 aloisio@gmx.com
- Update to version 6.12.0
  Framework:
  * Changed buffer property to be mutable and adaptive to speed
    property in mlt_consumer.
  * Changed macOS RELOCATABLE build to use standard app bundle
    layout:
    + lib/mlt      -> ../PlugIns/mlt
    + lib/frei0r-1 -> ../PlugIns/frei0r-1
    + lib/ladspa   -> ../PlugIns/ladspa
    + share/mlt    -> ../Resources/mlt
    + share/movit  -> ../Resources/movit
  * Fixed a_track of transitions matching deleted track in
    mlt_tractor_remove_track().
  * Fixed multi-thread race crash in mlt_properties_clear().
  * Fixed possiblle null pointer crash in
    mlt_property_get_rect() and mlt_property_get_time().
  * Fixed non-animated strings containing ';' or '=' in
    mlt_animation_parse().
  * Fixed crash in clear_property() with mlt_animation.
  Modules:
  * Added a generic text filter to the plus module.
  * Added a timer filter to the plus module.
  * Added audio timeout handling to sdl2 consumers.
  * Added spot_remove filter to the plus module.
  * Added dds, ico, and webp filename extensions for qimage
    producer.
  * Added support for color_range property in avformat consumer:
    "pc" or "jpeg" for full range, otherwise limited range.
  * Added a window property to the audiowaveform filter.
  * Added MM:SS.SS to the timer filter.
  * Added query string param "multi" to the xml producer to
    force using the
    multi consumer.
  * Improved WebP image support in avformat producer.
  * Integrated hwupload filter in avformat consumer if using
    VAAPI codec.
  * Changed count producer to use pango if qtext not available.
  * Changed qt moduled to not call XInitThreads()
  * Changed color producer to only set alpha on frame if rgb24a
    requested or not opaque.
  * Changed the xml producer to pass quality and performance
    parameters to the multi consumer.
  * Fixed sdl2_audio distortion (regression in v6.10.0).
  * Fixed dynamictext filter to not error on empty text.
  * Fixed dynamictext aliased (regression in v6.10.0).
  * Fixed qimage outputs premultiplied if scaled internally.
  * Fixed crash in cbrts consumer if running property was never
    set.
  * Fixed rendering edges of some typefaces in qtext producer.
  * Fixed qimage fails to load with wrong filename extension.
  * Fixed affine dark right and bottom edge artifacts regression
    in (v6.10.0).
  * Fixed support for vp8 and vp9 with alpha channel in avformat
    producer.
  * Fixed interpolation mode selection in qimage producer.
  * Fixed crash in qimage with alpha channel.
  * Fixed some AAC MP4 files start playing from middle in
    avformat producer.
  * Fixed crash in avfilter if initialization fails.
  * Fixed crash in mix when frame rate is very low.
  * Fixed crash on missing luma file in composite transition.
  * Fixed A/V sync on some files in avformat producer.
  * Fixed seeking on audio filter with album art in avformat
    producer.
  * Fixed colorspace conversion in avformat consumer.
  Other:
  * Added more avformat consumer presets:
    + alpha/Quicktime Animation
    + alpha/vp8
    + alpha/vp9
    + alpha/Ut Video
    + lossless/Ut Video
  * Added square video profiles:
    + square_1080p_30
    + square_1080p_60
  * Added support for nodejs to the swig bindings.
  * Changed configure script to require opencv module be
    explicitly enabled.
  * Numerous spelling fixes in source code and comments thanks
    to codespell.
* Sun Oct 21 2018 davejplater@gmail.com
- Disabled build of opencv module to fix boo#1068792.
- Only build sdl2 module.
* Mon Jul  2 2018 aloisio@gmx.com
- Update to version 6.10.0
  * This version fixes bugs and supports serializing animation
    keyframes with a specified time format (previously only
    frame number).
  Framework:
  * Reverted mlt_pool change in v6.8.0 pending further testing.
    (USE_MLT_POOL compiler define is now a 0/1 boolean, defaults
    to 1.)
  * Fixed crash regression in v6.8.0 "parsing non-animated
    string as an animation."
  * Added pointer checks to mlt_animation.
  * Changed producer cache size heuristic in mlt_multitrack to
    be more liberal.
  * Fixed handling reserved characters in names for YAML in
    mlt_properties.
  * Added clamping to prevent computing negative in and out
    points to mlt_producer.
  * Added functions to serialize animation with a time format:
    + mlt_animation_serialize_cut_tf()
    + mlt_animation_serialize_tf()
    + mlt_property_get_string_tf()
    + mlt_property_get_string_l_tf()
    + mlt_properties_get_value_tf()
    + Mlt::Properties::get(int, mlt_time_format)
    + Mlt::Animation::serialize_cut(mlt_time_format, int, int)
  * Added functions to clear a property to mlt_properties:
    + mlt_property_clear()
    + mlt_properties_clear()
    + Mlt::Properties::clear()
  Modules:
  * Fixed enabling sliced pix_fmt conversion in avformat
    producer.
  * Fixed incorrect seek and sync on audio files with discard
    packets.
  * Added support for avcodec_send_frame() API to avformat
    consumer.
  * Fixed compile errors with Libav master.
  * Fixed a crash in affine transition.
  * Fixed a crash in ladspa filters when consumer frame rate is
    low (e.g. <= 8).
  * Fixed a crash in boxblur filter.
  * Added animation support to boxblur hori and vert properties.
  * Fixed a crash in movit.convert.
  * Fixed incorrect alpha in affine transition blending routine.
  * Converted frei0r from deprecated mlt_geometry to
    mlt_animation API.
  * Fixed tilde in text string for pango producer.
  * Fixed using more than one channelcopy filter.
  * Fixed the mono filter reducing volume level.
  * Fixed degraded audio scrubbing in sdl2_audio consumer.
  * Converted dynamictext filter to use affine transition for
    more correct
    alpha compositing and sub-pixel positioning.
  * Added time format support for animation keyframes to the xml
    consumer.
  * Added animation support to more affine transition properties:
    + fix_rotate_x
    + fix_rotate_y
    + fix_rotate_z
    + fix_shear_x
    + fix_shear_y
    + fix_shear_z
    + ox
    + oy
    + scale_x
    + scale_y
  * Fixed gaps in text when characters overlap in qtext and
    kdenlive producers.
  * Fixed a crash in pixbuf producer with multiple render
    threads.
  * Converted the oldfilm vignette filter from mlt_geometry to
    mlt_animation.
  Other:
  * Numerous updates to mlt-xml.dtd.
  * Categorized many of the encode presets (using
    meta.preset.name).
* Wed Jun 20 2018 aloisio@gmx.com
- Update to version 6.8.0
  * This version improves support for multi-channel audio and
    adds some new manipulation functions to the mlt_animation
    API.
  Framework:
  * Added support for musl C library.
  * Added functions for audio channel layouts:
    + mlt_channel_layout_name()
    + mlt_channel_layout_id()
    + mlt_channel_layout_channels()
    + mlt_channel_layout_default()
  * Added channel_layout property to mlt_consumer.
  * Added mlt_channel_layout enum.
  * Disabled memory pooling by default and require compile macro
    USE_MLT_POOL to re-enable it.
  * Fixed reliability of keyframed properties serializing
    properly.
  * Fixed parsing non-animated string as an animation.
  * Added more functions to mlt_animation:
    + mlt_animation_key_set_type()
    + mlt_animation_key_set_frame()
    + Mlt::Animation::key_set_type()
    + Mlt::Animation::key_set_frame()
  Modules:
  * Fixed some crashes in qimage producer especially with alpha
    channel.
  * Fixed >2 channel audio output in the SDL consumers.
  * Fixed >2 channel audio output in the rtaudio consumer on
    Windows.
  * Fixed vorbis encoding with FFmpeg v3.4+.
  * qimage and qtext are now higher priority than gtk2 pixbuf
    and pango by the loader producer.
  * Added support for more channel counts to decklink consumer.
  * Added swresample filter based on libswresample from FFmpeg.
    This is now the preferred channel count normalizing filter
    used by the loader producer.
  * Fixed the strange "Undefined constant" and "Unable to parse
    option value" log messages in the the avformat consumer.
  * Fixed GIF and DPX writing in avformat consumer.
  * Reduced the memory usage of the affine transition and
    filters.
  * Fixed a crash in kdenlivetitle producer.
  * Fixed a crash in the rotoscoping filter.
  * Fixed frame rate reported in Matroska and WebM files
    produced by the avformat consumer.
  * Added sdl2_audio consumer.
  * Fixed alpha channel support for more pixel formats in the
    avformat producer.
  * Converted the affine transition to use mlt_rect and
    mlt_animation.
  * Fixed LADSPA plugins with mono channel audio.
  Other:
  * Fixed a melt command line parsing bug when argument supplied
    to -transition.
  * Fixed melt with SDL2 on Windows not using stdio and stderr.
  * Improved speed of the vp9 avformat consumer preset.
* Mon Jun 18 2018 bjorn.lie@gmail.com
- Enable pkgconfig(vidstab) BuildRequires unconditionally, now
  available in openSUSE.
- Build with ffmpeg unconditionally, ffmpeg is available in
  openSUSE.
* Sun May  6 2018 davejplater@gmail.com
- Update to 6.6.0+git20180502 to enable shotcut 18.05 to build.
- Upstream changes:
  * Fix affine and region filters alter the frame's position.
  * Fix mono channel configuration for ladspa plugins. (#334)
  * Convert affine to mlt_rect and animation APIs.
  * Add mlt_animation_key_set_frame() and Animation::key_set_frame().
  * Fix build for Libav
  * Fix crash on composite transition with unexpected pgm luma
  https://bugs.kde.org/show_bug.cgi?id=381110
  * Fix alpha support for more pixel formats Kdenlive issue #391963
  * Add mlt_animation_key_set_type() and Animation::key_set_type().
  * Fix rotoscoping crash
  * Fix parsing non-animation string as animation.
  * Fix mlt_animations not reliably serializing.
  * Fix crash with kdenlivetile caused by wrong malloc size
  * Add filter_swresample. (#305)
  * Fix #284 GIF encoding not working.
  * Fix segmentation fault when using qimage png producer #296
* Sun Apr  1 2018 avvissu@yandex.by
- Build with sdl and sdl2:
  * Preserve backward compatibility. Both "sdl" and "sdl2" modules
  can be compiled into MLT 6.6.0 and later
* Mon Mar  5 2018 davejplater@gmail.com
- Build with SDL2.
* Wed Jan 24 2018 davejplater@gmail.com
- Update to release 6.6.0 and build with gcc7
- Combined melt6 sub package into melt subpackage.
- Remove incorporated patches:
  6c658e5d8cd11933bf799a2a985aa4b24cfbcb60.patch, rem_close.patch,
  use-recommended-freetype-include.patch and
  libmlt-nomorexlocale_h.patch.
- Upstream changes:
  This version builds upon the previous release with performance
  improvements using the sliced image processing framework.
  It also improves compatibility with dependencies
  (FFmpeg, Qt 5, SDL 2, NDI, OpenCV, libebur128).
  For full details see:
  /usr/share/doc/packages/libmlt6/NEWS
* Fri Aug 25 2017 davejplater@gmail.com
- Fix build against glibc-2.26 with libmlt-nomorexlocale_h.patch.
- Rebased 6c658e5d8cd11933bf799a2a985aa4b24cfbcb60.patch,
  libmlt-0.8.2-vdpau.patch, rem_close.patch and
  use-recommended-freetype-include.patch.
* Sat Aug  5 2017 olaf@aepfle.de
- Build with Qt5 unconditional because PackageHub has a recent Qt5
* Thu Jul 13 2017 davejplater@gmail.com
- Build with gcc6, fix build failure for 42.2/3 due to movit
  building with gcc6.
* Thu Jul  6 2017 jengelh@inai.de
- Trim filler wording from descriptions; fix identical
  descriptions being used in different subpackages.
* Wed Jul  5 2017 klaas.freitag@suse.com
- Add rem_close.patch from upstream that prevents crashes of apps
  in some circumstances, as reported on openSUSE ML.
  https://github.com/mltframework/mlt/commit/a3188e301b5a9a1f25dbb98a510e366363348e64
* Fri Jun  9 2017 davejplater@gmail.com
- Added files for linked package webvfx which provides qmelt needed
  by shotcut for video export see boo#1043070. Webvfx has to build
  within the mlt sources.
* Tue Feb 21 2017 mrueckert@suse.de
- replace mlt-6.4.1_fix_opengl_install.patch with
  6c658e5d8cd11933bf799a2a985aa4b24cfbcb60.patch:
  upstream solution to the problem
* Tue Feb 21 2017 mrueckert@suse.de
- enable OpenGL and OpenVC modules
  new BR:
  - OpenGL: movit-devel
  - OpenVC: pkgconfig(openvc)
- added mlt-6.4.1_fix_opengl_install.patch: fix install of OpenGL
  filter files.
* Wed Nov 16 2016 aloisio@gmx.com
- Update to version 6.4.1
  * This is a hot-fix release for v6.4 that fixes a symbol
    version declaration problem for the new C++ method
    Mlt::Profile::is_valid().
* Sat Nov 12 2016 aloisio@gmx.com
- Update to version 6.4.0
  This is both a bugfix and enhancement release:
  Framework
  * Added functions for multi-threaded slice-based image processing:
    mlt_slices_init, mlt_slices_close, and mlt_slices_run.
  * Added Mlt::Profile::is_valid().
  * Added MLT_DIRLIST_DELIMITER to mlt_types.h.
  * Renamed mlt++/config.h to mlt++/MltConfig.h.
  * Fixed mlt_properties_set_lcnumeric() on macOS.
  * Fixed address of Free Software Foundation in comment headers.
  Modules
  * Added crop_to_fill property to composite transition.
  * Added sliced_composite property to composite transition.
  * Added peak and true peak properties to loudness_meter filter.
  * Added qtblend transition and filter to qt module.
  * Added ndi (NewTek NDI) module with producer and consumer.
  * Added opencv module with opencv_tracker filter.
  * Added line_spacing, strech, wrap_width, and wrap_type properties to
    pango producer.
  * Added oblique value for style property to pango producer.
  * Added fontmap-reload event to pango producer.
  * Added support for pkg-config to sdl module.
  * Added .kra (Krita Image) file name extension to loader.dict.
  * Improved performance of kdenlivetitle producer.
  * Improved decklink producer and consumer.
  * Improved accuracy of seeking on lossy compressed audio in
    avformat producer.
  * Improved mix transition using 32-bit floating point.
  * Fixed avfilter when image format changes.
  * Fixed loading relative file name in vidstab filter.
  * Fixed crash on Windows with avfilter.
  * Fixed parsing LADSPA_PATH with semi-colon delimiter on Windows.
  * Fixed parsing FREI0R_PATH with semi-colon delimiter on Windows.
  * Fixed reading relative path with backslash (Windows) in xml producer.
  * Fixed loading relative file name for av.file (avfilter).
  * Fixed loading multiple LADSPA plugins on some systems.
  * Fixed compile error when not configured with --enable-gpl.
  * Fixed loading in avfilter.lut3d in locales with comma decimal point.
  * Fixed a possible crash in resample filter.
  * Fixed alpha channel in kdenlivetitle producer.
  * Fixed possible crash in pixbuf and qimage producers.
  * Fixed count when counting down in count producer.
  Other
  * Moved some avformat presets from lossless to new intermediate folder.
  * Added a YouTube avformat consumer preset.
  * Changed metadata.rb metadata publisher to output Markdown.
- Removed dupes
* Mon Jul 25 2016 olaf@aepfle.de
- Build with ffmpeg unconditional
* Thu Apr 21 2016 zaitor@opensuse.org
- Update to version 6.2.0:
  + There are no framework changes in this release. The major
    announcement is the introduction of support for libavfilter!
    This is still a work-in-progress. It is limited to FFmpeg 2.3
    and up, and there are a number of filters that are black-listed
    because they are known to not integrate with MLT, which is not
    a full libav* environment or simple wrapper for it. There are
    likey avfilters that are not yet black-listed but might not
    work because they have not been completely tested. Also, they
    do not support MLT's keyframable property animation nor its
    frame-threaded parallelism due to architectural or integration
    limitations. However, some avfilters are slice-threaded
    (internal parallelism), and that works. Finally, libavfilter
    filtergraph syntax is not supported either.
    All of the supported libavfilters are exposed as MLT filters
    beginning with the prefix "avfilter." All of the avfilter
    parameters are exposed as MLT properties with the "av." prefix
    to prevent clashes with MLT properties. You can run `melt
  - query filters` to see the new avfilters, and `melt -query
    filter=avfilter.rotate`, for example, to view generated
    documentation for an individual filter.
  + Notable fixes and enhancements in this release:
  - Added support for libavfilter to avformat module.
  - Added auto-rotate support to avformat producer.
  - Added animated GIF preset for avformat consumer.
  - Prevent serializing and deserializing mlt_type property to
    xml module.
  - Fixed relative paths for WebVfx "plain:" resources in xml
    module.
  - Updated libebur128 to v1.1.0 in plus module.
  - Added dynamic_loudness filter to plus module.
  - Added loudness_meter filter to plus module.
  - Qt 5 fixes for kdenlivetitle producer.
  - Added gradients and text shadows to kdenlivetitle producer.
  - Added support for building rtaudio against external build of
    lib.
  - Upgraded bundled RtAudio to v4.1.2.
  - Added status parameters to ladspa producer and filters.
  - dded 5.1 surround to stereo downmix to audiochannels filter
    in core module.
  - Fixed compiling SWIG bindings for Ruby 2.0.
- Changes from version 6.0.0:
  + This is a bugfix and minor enhancement release. Note that our
    release versioning scheme has changed. We were approaching 1.0
    but decided to synchronize release version with the C library
    ABI version, which is currently at v6. Here are some of the
    notable changes and enhancements:
  + Framework:
  - Added unit tests for tractor, multitrack, and field.
  - Deprecate mlt_frame_get_alpha_mask().
  - Added drop_count readable property to mlt_consumer.
  - Added mlt_factory_repository().
  - Added mlt_properties_to_utf8().
  - Define MIN, MAX, CLAMP in mlt_types.h in not already defined.
  - Switched to APPLE and _WIN32 defines throughout codebase.
  + Modules:
  - Added UDP and SMPTE 2022-2 support to cbrts consumer.
  - Fixed build against latest FFmpeg versions - now requires
    v1.1 and up.
  - Added audiospectrum filter to qt module.
  - Added meta.media.0.codec.rotate property to avformat producer
    to let apps and other services get the media orientation.
  - Make the avformat producer handle animated images.
  - Added style property to dynamictext filter.
  - Added timewarp producer to core module.
  - Fixed slowly accumulating A/V sync drift in mix audio
    transition.
  - Added width_crop and width_fit properties to pango producer.
  + Melt:
  - Added -abort option to simply exit without full cleanup.
  - Fix key-press handling on Windows.
- Add pkgconfig(libpulse) BuildRequires: Build pulseaudio support.
- Add pkgconfig(Qt5OpenGL) BuildRequires: Build qt5 opengl support.
- Add pkgconfig(fftw3) BuildRequires: Build lightshow, fft and
  dance filters.
- Drop libmlt-ffmpeg3.patch: Fixed upstream.
* Thu Feb 18 2016 olaf@aepfle.de
- Remove usage of depcrecated functions
  libmlt-ffmpeg3.patch
* Mon Nov 16 2015 olaf@aepfle.de
- Restore pkgconfig(libavdevice), multiple providers should be
  solved with Prefer: pkg in prjconf
* Fri Nov 13 2015 wbauer@tmo.at
- Build with ffmpeg on Leap and Tumbleweed by default to make it a
  bit more useful (boo#954841)
- Replace pkgconfig(libavdevice) BuildRequires with
  libavdevice-devel to prevent an unresolveable choice between that
  and libavdevice-libav-devel
* Thu Nov  5 2015 wbauer@tmo.at
- Build against Qt5 on Leap as well, the included kdenlive 15.08.1
  (which is KF5/Qt5 based) will crash on startup otherwise (boo#930616)
* Fri Aug  7 2015 fisiu@opensuse.org
- Update to 0.9.8
  + Framework
  * Added mlt_service_disconnect_producer() and
    Mlt::Service::disconnect_producer().
  * Added mlt_multitrack_disconnect() and Mlt::Multitrack::disconnect().
  * Added mlt_tractor_remove_track() and Mlt::Tractor::remove_track().
  * Added mlt_service_insert_producer() and Mlt::Service::insert_producer().
  * Added mlt_multitrack_insert() and Mlt::Multitrack::insert().
  * Added mlt_tractor_insert_track() and Mlt::Tractor::insert_track().
  * Added mlt_transition_set_tracks() and Mlt::Transition::set_tracks().
  * Added Mlt::Properties::get_animation().
  * Added Mlt::Properties::get_anim().
  * Added Mlt:Animation class with methods: length(), is_key(),
    keyframe_type(), get_item(), next_key(), previous_key(), set_length(),
    remove(), interpolate(), serialize_cut().
  * Added mlt_animation_key_count() and Mlt::Animation::key_count().
  * Added mlt_animation_key_get() and Mlt::Animation::key_get().
  + Modules
  * Added audiowaveform video filter.
  * Added fft audio filter.
  * Added dance video filter (uses fft).
  * Added lighshow video filter (uses fft).
  * Added distort property to movit.rect video filter.
  * Added rotate property to pango video producer.
  * Added 2K DCI and 4K modes to decklink producer and consumer.
  * Added audiomap (channel remapping) filter.
  * Added property animation to all LADSPA audio filters and producers.
* Sun Apr 19 2015 tittiatcoke@gmail.com
- libmlt for Tumbleweed/Factory is now QT5 based !!
- Update to 0.9.6
  + Framework
  * Added color_trc (transfer characteristic) property to mlt_consumer and mlt_frame.
  * Added Mlt::Profile::set_display_aspect(int, int).
  * Added mlt_pool_stat().
  * Added mlt_smpte_df and mlt_smpte_ndf to mlt_time_format for non-drop-frame timecode support.
  * Added Mlt::Tractor::Tractor(Mlt::Profile&).
  * Added mlt_frame_get_alpha().
  * Added default, copy, and assignment methods to Mlt::Frame.
  * Added Mlt::Filter::process(Mlt::Frame&).
  + Modules
  * Added support for color_trc property to avformat and opengl modules.
  * Performance improvements for composite and matte transitions.
  * Added fill, halign, and valign properties to affine transition and filter.
  * Added producer.* and consumer.* properties to consumer producer.
  * Fixes for libavformat and libavcodec v56.
  * Dropped support for FFmpeg < v1.0 and Libav < v9.
  * Added a lumakey filter.
  * Added a localtime property to dynamictext filter.
  * Added date/time format string support to dynamictext filter.
  * Added no_root property to xml consumer.
  * Added audio-only tone producer.
  * Added drop property to count producer.
  * Added caching to pango producer to improve performance.
  + Other
  * Added WMV and WMA avformat consumer presets.
  * Added a ProRes-Kostya avformat consumer preset.
  * Changed VP9 WebM preset to use Opus audio codec.
  * Added 4K UHD and 2.5K QHD profiles.
  * Added x265-medium and x265-medium-pass1 avformat consumer presets.
  * Added a unit test for Mlt::Frame.
- Drop upstreamed patches
  * mlt-0.9.2-Add-missing-stdlib-include-for-getenv.patch
* Tue Nov 11 2014 dimstar@opensuse.org
- Temporarly disabled vid.stab support, as the submission to
  Tumbleweed hit a legal road bump. While it's enabled in the devel
  project, other packages depending on libmlt are being blocked.
* Tue Nov  4 2014 olaf@aepfle.de
- Enable exif support
- Add missing stdlib.h inclusion in qt
  (mlt-0.9.2-Add-missing-stdlib-include-for-getenv.patch)
* Sat Oct 25 2014 reddwarf@opensuse.org
- Add vid.stab support
  Add BuildRequires: pkgconfig(vidstab)
* Thu Oct 16 2014 nico.kruber@gmail.com
- Update to 0.9.2
  + Framework
  * Added "boolean" parameter type and "argument" parameter
    attribute to service metadata schema.
  * Added mlt_properties_frames_to_time().
  * Added mlt_properties_time_to_frames().
  * Changed mlt_events_fire() to return the number of listeners.
  * Added consumer-thread-create and consumer-thread-join events.
  * Added LC_NUMERIC handling for Windows.
  * Added mlt_playlist_mix_out() and mlt_playlist_mix_in().
  * Added mlt_properties_from_utf8().
  + Modules
  * Renamed "qimage" module to "qt".
  * Added support for Qt 5.
  * Added qtext producer, which is now prefered by dynamictext
    filter over pango.
  * Added xml-nogl consumer.
  * Consolidated dgraft, burningtv, and rotoscoping into new
    plusgpl module.
  * Added vid.stab module with vidstab and deshake filters. This
    depends on external vid.stab library unlike its predecessors.
  * Rewrote opengl module.
  * Added loudness filter based on EBU R128.
  * Added rgblut filter to plus module.
  * Added luma-only liftgammagain filter to plusgpl module.
  * Added lift_gamma_gain filter to plus module.
  * Added support new keyframable animated properties to brightness,
    volume, panner, boxblur, wave, sepia, charcoal, burn, gamma,
    grain, dust, lines, tcolor, oldfilm.
  * Added movit.luma transition to opengl module.
  * Added cbrts consumer to plusgpl module.
  * Removed the "ppm" PPM-pipe producer.
  * Added more VITC functionality to decklink module.
  * Added matte transition to core module.
  + DEPRECATION WARNINGS
  * Deprecate videostab module with videostab and videostab filters.
    This will not be removed soon in order to keep old scripts and
    projects functional.
  * Deprecate the dv (libdv), kino, and vorbis modules. These are
    scheduled to be removed in next release.
- Update use-recommended-freetype-include.patch
* Wed Dec 11 2013 hrvoje.senjan@gmail.com
- Added use-recommended-freetype-include.patch -- Freetype upstream
  recommends using their macros together with ft2build include.
  Positive sideeffect is that this patch makes it build with both
  freetype2 2.5.1, and older version
* Sun Jun 30 2013 tittiatcoke@gmail.com
- Update to 0.9.0
  * new, properly integrated property animation API
  * Improved pause behavior when using buffered rendering in
    mlt_consumer.
  * Added mlt_color type.
  * Deprecated mlt_geometry API.
  * Support for the latest versions of FFmpeg and Libav (but
    dropping support for 0.5 and 0.6 versions).
  * Added alpha channel output to avformat consumer.
  * Added reconnect and exit_on_disconnect properties to avformat
    producer.
  * Added qglsl consumer to use opengl with avformat, sdi, and
    decklink.
  * Added avsync module with blipflash producer and consumer for
    testing.
  * Added new "count" producer to gtk2 module.
  * Changed frei0r to use index-based property names making it
    impervious to param name changes (param name still accepted
    for compatibility).
  * Added default parameter values to frei0r metadata.
  * Added more python example web services.
  * Started a unit test suite.
- Dropped patch libmlt-0.8.0-versioned_dirs.patch due to upstream
  support for versioning (--enable-extra-versioning configure flag)
* Thu May  2 2013 reddwarf@opensuse.org
- By default disable VDPAU as requested by Dan Dennedy
* Fri Apr 19 2013 tiwai@suse.de
- Fix missing buildrequire for alsa-devel
* Mon Jan 21 2013 reddwarf@opensuse.org
- Update to 0.8.8
  * Purely a bugfix release
* Fri Nov 30 2012 reddwarf@opensuse.org
- Make multiple versions of melt parallel installable
* Tue Nov 27 2012 crrodriguez@opensuse.org
- Fix build in non-x86 platforms (ARM, PPC ETC..)
* Thu Nov 15 2012 reddwarf@opensuse.org
- Update to 0.8.6
  * Fix a performance regression on videos that use full-range
    colorspaces such as yuv420p.
* Wed Nov 14 2012 reddwarf@opensuse.org
- Update to 0.8.4
  * Added playlist-next event and PlaylistNextListener to Ruby binding
  * FFmpeg 1.0 and libAV master compatibility
  * Improvements to motion_est filter to generate keyframes for apps
  * Added audiolevel (measurement) filter
- Remove libmlt-0.8.2-ffmpeg1.patch and libmlt-0.8.0-optflags.patch.
  Have been applied upstream.
* Mon Oct  1 2012 reddwarf@opensuse.org
- Add libmlt-0.8.2-ffmpeg1.patch to fix build with ffmpeg 1.0
* Thu Aug 30 2012 reddwarf@opensuse.org
- Update to 0.8.2
  * Overhaul of A/V sync with libavformat-based inputs.
  * Fix a major memory leak introduced in previous release.
  * Fixes to problems revealed by Coverity Scan static analysis.
  * Improved encoding presets.
  * melt can now be built without SDL with define MELT_NOSDL, which is handy
    for running it as a child process on Windows and OS X.
  * melt can now be signaled to quit, which also makes it more useful as a
    child process.
- Rebase libmlt-0.8.2-vdpau.patch
- Remove libmlt-0.8.0-fix_null_pointer_dereference.patch. Applied upstream.
* Mon Aug 27 2012 toddrme2178@gmail.com
- Added libmlt-0.8.0-fix_null_pointer_dereference.patch, fixed
  upstream.  See and BNC # 777416 and upstream comit
  17a64a9aa20aa27861b6169e38859358a323c5a8
* Sat Aug 25 2012 reddwarf@opensuse.org
- Make python-mlt require at least the same version of libmlt++
* Fri Aug 17 2012 reddwarf@opensuse.org
- Make vdpau support work without the need of the devel package
* Thu Aug 16 2012 reddwarf@opensuse.org
- Package module specific data in the -modules subpackage
* Sun Aug 12 2012 reddwarf@opensuse.org
- Add modules and data directories as variables in the .pc file
* Tue Aug  7 2012 reddwarf@opensuse.org
- Version modules and data directories
- Put the full python module in %%python_sitearch
- Added "mlt(%%{soname})(avformat)" and "python-%%{_name}%%{soname}"
  provides to help openshot select the versions it needs
* Sat Aug  4 2012 reddwarf@opensuse.org
- Compile the python binding with %%{optflags}, getting debug
  information on the way.
- Fix VDPAU support
* Mon Jun 18 2012 reddwarf@opensuse.org
- Update to 0.8.0
  + Addition of time properties
  + ABI incompatible changes to some mlt_property functions
  + Improve seek speed on AVCHD when using FFmpeg v0.9.1+ (NOT
    Libav!)
  + Composite and dissolve speed improvements on x86-64
  + Improve performance of caching in image producers
  + Add device enumeration to decklink producer and consumer
- Remove included copy of GPLv3, upstream added it
- Remove dependency to x11 when unneeded
- Enable VDPAU support in the avformat module
* Tue Mar 27 2012 idonmez@suse.com
- Set license to GPLv3 for discussion in bnc#753622
* Sat Mar 10 2012 idonmez@suse.com
- Drop swfdec dependency, swfdec is not maintained.
* Thu Feb 23 2012 reddwarf@opensuse.org
- Update to 0.7.8
* Sun Jan  2 2011 reddwarf@opensuse.org
- Initial package
